CorePaint class

Constructors

CorePaint({required double height, required double width, required double topRight, required double bottomRight, required double topLeft, required double bottomLeft, required Options optionsParam})

Properties

bottomLeft ↔ double
latefinal
bottomRight ↔ double
latefinal
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
latefinal
optionsParam ↔ Options
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamListLayerModel → Stream<List<LayerModel>>
no setter
topLeft ↔ double
latefinal
topRight ↔ double
latefinal
updatePointsStream → StreamSink<List<TouchModel>>
no setter
width ↔ double
latefinal

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited