TouchModel class

Constructors

TouchModel({required double x, required double y, required double z, required double force, required bool isShow})
Создание модели касания экрана

Properties

force ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isShow ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair
z ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited