Options class

Constructors

Options({double tension = 0.45, double width = 50, double height = 20, double hoverFactor = -0.3, double gap = 5, double forceFactor = 0.15, double forceFactorBuild = 1, double forceFactorOnTap = 1, List<LayerModel>? layers, List<TouchModel>? touches, List<int>? layerNumbers, List<double>? scaleOptionLayer, double noise = 0})
Designer with liquid widget settings

Properties

corePaint ↔ CorePaint?
getter/setter pair
forceFactor ↔ double
getter/setter pair
forceFactorBuild ↔ double
Perturbation of the liquid widget when it is built
getter/setter pair
forceFactorOnTap ↔ double
Liquid widget disturbance when pressed
getter/setter pair
gap ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
hoverFactor ↔ double
getter/setter pair
layerNumbers ↔ List<int>
getter/setter pair
layers ↔ List<LayerModel>
getter/setter pair
layerScales ↔ List<double>
getter/setter pair
noise ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tension ↔ double
getter/setter pair
touches ↔ List<TouchModel>
getter/setter pair
width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshLayerModel() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited